/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#ifndef CUBIDEFINES_H
#define CUBIDEFINES_H

#include "infixfunction.h"
#include "prefixfunction.h"

CUBI_BEGIN_NAMESPACE

namespace Functions {
	// Core functions
    static const InfixFunction and_(QLatin1String("&&"));
    static const PrefixFunction bound(QLatin1String("bound"));
    static const InfixFunction equal(QLatin1String("="));
    static const InfixFunction greaterThan(QLatin1String(">"));
    static const InfixFunction greaterThanOrEqual(QLatin1String(">="));
    static const PrefixFunction groupConcat(QLatin1String("GROUP_CONCAT"));
    static const InfixFunction in(QLatin1String("IN"));
    static const InfixFunction lessThan(QLatin1String("<"));
    static const InfixFunction lessThanOrEqual(QLatin1String("<="));
    static const InfixFunction notIn(QLatin1String("NOT IN"));
    static const PrefixFunction not_(QLatin1String("!"));
    static const InfixFunction notEquals(QLatin1String("!="));
    static const InfixFunction or_(QLatin1String("||"));

	// XPATH functions
    static const PrefixFunction concat(QLatin1String("fn:concat"));
    static const PrefixFunction contains(QLatin1String("fn:contains"));
    static const PrefixFunction dayFromDateTime(QLatin1String("fn:day-from-dateTime"));
    static const PrefixFunction endsWith(QLatin1String("fn:ends-with"));
    static const PrefixFunction hoursFromDateTime(QLatin1String("fn:hours-from-dateTime"));
    static const PrefixFunction lowerCase(QLatin1String("fn:lower-case"));
    static const PrefixFunction minutesFromDateTime(QLatin1String("fn:minutes-from-dateTime"));
    static const PrefixFunction monthFromDateTime(QLatin1String("fn:month-from-dateTime"));
    static const PrefixFunction secondsFromDateTime(QLatin1String("fn:seconds-from-dateTime"));
    static const PrefixFunction startsWith(QLatin1String("fn:starts-with"));
    static const PrefixFunction str(QLatin1String("str"));
    static const PrefixFunction stringJoin(QLatin1String("fn:string-join"));
    static const PrefixFunction substring(QLatin1String("fn:substring"));
    static const PrefixFunction timezoneFromDateTime(QLatin1String("fn:timezone-from-dateTime"));
    static const PrefixFunction yearFromDateTime(QLatin1String("fn:year-from-dateTime"));

	// Tracker functions
    static const PrefixFunction coalesce(QLatin1String("tracker:coalesce"));
    static const PrefixFunction ftsRank(QLatin1String("fts:rank"));
    static const PrefixFunction ftsOffsets(QLatin1String("fts:offsets"));
    static const PrefixFunction trackerAsciiLowerCase(QLatin1String("tracker:ascii-lower-case"));
    static const PrefixFunction trackerCaseFold(QLatin1String("tracker:case-fold"));
    static const PrefixFunction trackerId(QLatin1String("tracker:id"));
    static const PrefixFunction trackerUri(QLatin1String("tracker:uri"));
};

CUBI_END_NAMESPACE

#endif
