/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#include "exists.h"

#include "patterngroup_p.h"

CUBI_BEGIN_NAMESPACE

/*! \cond DOCUMENT_DATA_CLASSES */
class ExistsData : public PatternGroupData
{

public:
	PatternBaseData * clone();
	virtual bool operator==(const PatternBaseData *other) const;
	virtual bool isExists() const;
	virtual PatternBase::Type type() const;
	virtual bool isValid() const;
	virtual QString sparql(Options::SparqlOptions options) const;
};
/*! \endcond */

PatternBaseData*
ExistsData::clone()
{
	return new ExistsData(*this);
}

bool
ExistsData::operator==(const PatternBaseData *other) const
{
	if (type() != other->type()) {
		return false;
	}

	return PatternGroupData::operator==(other);
}

bool
ExistsData::isExists() const
{
	return true;
}

PatternBase::Type
ExistsData::type() const
{
	return PatternBase::TypeExists;
}

bool
ExistsData::isValid() const
{
	return true;
}

QString
ExistsData::sparql(Options::SparqlOptions options) const
{
	static const QString existsTemplate = QString::fromLatin1("EXISTS {%1}");
	static const QString existsTemplatePretty = QString::fromLatin1("EXISTS {\n%1\n}");

	return (options & Options::PrettyPrint) ? existsTemplatePretty.arg(PatternGroupData::sparql(options))
	                                        : existsTemplate.arg(PatternGroupData::sparql(options));
}

CUBI_END_NAMESPACE

///////////////////////////////////////////////////////////////////////////////

CUBI_USE_NAMESPACE

/*!
 * \class Exists
 * Models a Sparql EXISTS contruct.
 */

/*!
 * Constructs a graph with an IRI.
 */
Exists::Exists()
	: PatternGroup(new ExistsData)
{
}

const ExistsData*
Exists::data() const
{
	return static_cast<const ExistsData *>(d.constData());
}

ExistsData*
Exists::data()
{
	return static_cast<ExistsData *>(d.data());
}
