/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#ifndef CUBI_FILTER_GROUP_P_H
#define CUBI_FILTER_GROUP_P_H

#include "value.h"

CUBI_BEGIN_NAMESPACE

class FilterData;

class Exists;
class LiteralValue;
class Function;
class Select;

class Filter : public Value {

public:
	Filter();
	CUBI_EXPLICIT Filter(const Exists &exists);
	CUBI_EXPLICIT Filter(const Function &function);
	CUBI_EXPLICIT Filter(const LiteralValue &literal);
	CUBI_EXPLICIT Filter(const Select &select);

	enum Type {
		InvalidFilter,
		FunctionFilter,
		SelectFilter,
		ExistsFilter,
		LiteralFilter
	};

	Type filterType() const;

	Exists exists() const;
	Function function() const;
	LiteralValue literalValue() const;
	Select select() const;

private:
	const FilterData * data() const;
	FilterData * data();
};

CUBI_END_NAMESPACE

#endif
