/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#include "generatedvariable.h"

#include "variable_p.h"

CUBI_BEGIN_NAMESPACE

/*! \cond DOCUMENT_DATA_CLASSES */
class GeneratedVariableData : public VariableData
{

public:
	virtual ValueData * clone();
	virtual QString sparql() const;
};
/*! \endcond */

ValueData*
GeneratedVariableData::clone()
{
	return new GeneratedVariableData(*this);
}

QString
GeneratedVariableData::sparql() const
{
	static const QString nameTemplate = QString::fromLatin1("?%1");
	return nameTemplate.arg(m_name);
}

CUBI_END_NAMESPACE

CUBI_USE_NAMESPACE

GeneratedVariable::GeneratedVariable(const QString &name)
	: Variable(new GeneratedVariableData)
{
	data()->m_name = name;
}

const GeneratedVariableData*
GeneratedVariable::data() const
{
	return static_cast<const GeneratedVariableData *>(d.constData());
}

GeneratedVariableData*
GeneratedVariable::data()
{
	return static_cast<GeneratedVariableData *>(d.data());
}
