/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#ifndef CUBI_PATTERN_H
#define CUBI_PATTERN_H

#include "patternbase.h"
#include "value.h"

CUBI_BEGIN_NAMESPACE

class PatternData;

class Pattern : public PatternBase
{

public:
	Pattern();
	Pattern(const Value &s, const Value &p, const Value &o);
	bool operator==(const Pattern &other) const;
	bool operator!=(const Pattern &other) const;

	void setSubject(const Value &subject);
	Value subject() const;
	void setPredicate(const Value &predicate);
	Value predicate() const;
	void setObject(const Value &object);
	Value object() const;

private:
	const PatternData * data() const;
	PatternData * data();
};

typedef QList<Pattern> PatternList;

inline uint
qHash(const Pattern &pattern)
{
	return qHash(pattern.sparql());
}


CUBI_END_NAMESPACE

#endif
