/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#include "patternbase.h"

#include "patternbase_p.h"

CUBI_USE_NAMESPACE

PatternBaseData*
PatternBaseData::clone()
{
	return new PatternBaseData(*this);
}

bool
PatternBaseData::operator==(const PatternBaseData *other) const
{
	return other->type() == PatternBase::TypeInvalid;
}

QString
PatternBaseData::sparql(Options::SparqlOptions /* options */) const
{
	return QString();
}

template<>
PatternBaseData *QSharedDataPointer<PatternBaseData>::clone()
{
	return d->clone();
}

PatternBase::PatternBase(const PatternBase &other)
	: d(other.d)
{
}

PatternBaseData::~PatternBaseData()
{
}

bool
PatternBaseData::isExists() const
{
	return false;
}

bool
PatternBaseData::isPattern() const
{
	return false;
}

bool
PatternBaseData::isPatternGroup() const
{
	return false;
}

bool
PatternBaseData::isGraph() const
{
	return false;
}

bool
PatternBaseData::isUnion() const
{
	return false;
}

bool
PatternBaseData::isCompositionalSelect() const
{
	return false;
}

PatternBase::Type
PatternBaseData::type() const
{
	return PatternBase::TypeInvalid;
}

bool
PatternBaseData::isValid() const
{
	return false;
}

///////////////////////////////////////////////////////////////////////////////

/*!
 * \class PatternBase
 * Common base for graph patterns.
 *
 * The PatternBase class serves as a common base for all graph patterns. It
 * does not provide any useful function to the user in itself.
 */

PatternBase::PatternBase()
	: d(new PatternBaseData)
{
}

PatternBase&
PatternBase::operator=(const PatternBase &other)
{
	return d = other.d, *this;
}

bool
PatternBase::operator==(const PatternBase &other) const
{
	return (*d.constData()) == other.d;
}

bool
PatternBase::operator!=(const PatternBase &other) const
{
	return not (*this == other);
}

PatternBase::~PatternBase()
{
}

PatternBase::PatternBase(PatternBaseData *data)
	: d(data)
{
}

/*!
 * Returns true if the instance is a Pattern.
 *
 * \deprecated Use type() instead.
 */
bool
PatternBase::isPattern() const
{
	return d->isPattern();
}

/*!
 * Returns true if the instance is a PatternGroup.
 *
 * \deprecated Use type() instead.
 */
bool
PatternBase::isPatternGroup() const
{
	return d->isPatternGroup();
}

/*!
 * Returns true if the instance is a Graph.
 *
 * \deprecated Use type() instead.
 */
bool
PatternBase::isGraph() const
{
	return d->isGraph();
}

/*!
 * Returns true if the instance is a Union.
 *
 * \deprecated Use type() instead.
 */
bool PatternBase::isUnion() const
{
	return d->isUnion();
}

/*!
 * Returns true if the instance is a CompositionalSelect.
 *
 * \deprecated Use type() instead.
 */
bool PatternBase::isCompositionalSelect() const
{
	return d->isCompositionalSelect();
}

/*!
 * Returns true if the instance is a Exists.
 *
 * \deprecated Use type() instead.
 */
bool PatternBase::isExists() const
{
	return d->isExists();
}

/*!
 * Returns the type of the PatternBase.
 */
PatternBase::Type
PatternBase::type() const
{
	return d->type();
}

/*!
 * Returns true if the pattern is valid.
 */
bool PatternBase::isValid() const
{
	return d->isValid();
}

QString
PatternBase::sparql(Options::SparqlOptions options) const
{
	return d->sparql(options);
}
