/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#ifndef CUBI_PATTERNBASE_H
#define CUBI_PATTERNBASE_H

#include "global.h"

#include <QtCore>

CUBI_BEGIN_NAMESPACE

class PatternBaseData;

class PatternBase
{

public:
	PatternBase();
	PatternBase(const PatternBase &other);
	PatternBase& operator=(const PatternBase &other);
	bool operator==(const PatternBase &other) const;
	bool operator!=(const PatternBase &other) const;
	~PatternBase();

	enum Type {
		TypeInvalid,
		TypePattern,
		TypePatternGroup,
		TypeUnion,
		TypeGraph,
		TypeExists,
		TypeCompositionalSelect
	};

	Q_DECL_DEPRECATED bool isExists() const;
	Q_DECL_DEPRECATED bool isPattern() const;
	Q_DECL_DEPRECATED bool isPatternGroup() const;
	Q_DECL_DEPRECATED bool isGraph() const;
	Q_DECL_DEPRECATED bool isUnion() const;
	Q_DECL_DEPRECATED bool isCompositionalSelect() const;
	Type type() const;
	bool isValid() const;

	QString sparql(Options::SparqlOptions options = Options::DefaultSparqlOptions) const;

protected:
	PatternBase(PatternBaseData *data);

	QSharedDataPointer<PatternBaseData> d;
};

CUBI_END_NAMESPACE

#endif
