/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#ifndef CUBI_PROJECTION_H
#define CUBI_PROJECTION_H

#include "function.h"
#include "literalvalue.h"
#include "variable.h"

CUBI_BEGIN_NAMESPACE

class ProjectionData;
class Select;

class Projection {

public:
	enum Type {
		VariableProjection,
		FunctionProjection,
		SelectProjection,
		LiteralProjection
	};

	CUBI_EXPLICIT Projection(const Variable &variable);
	CUBI_EXPLICIT Projection(const Function &function, const Variable &alias = Variable::invalid());
	CUBI_EXPLICIT Projection(const Select &select, const Variable &alias = Variable::invalid());
	CUBI_EXPLICIT Projection(const LiteralValue &value, const Variable &alias = Variable::invalid());
	Projection(const Projection &other);
	Projection& operator=(const Projection &other);
	bool operator==(const Projection &other) const;
	bool operator!=(const Projection &other) const;
	~Projection();

	Type type() const;

	Variable variable() const;
	Function function() const;
	Select select() const;
	LiteralValue literalValue() const;
	Variable alias() const;

	QString sparql(Options::SparqlOptions options = Options::DefaultSparqlOptions) const;

private:
	QSharedDataPointer<ProjectionData> d;
};

CUBI_END_NAMESPACE

#endif
