/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#ifndef CUBI_SELECT_H
#define CUBI_SELECT_H

#include "filter.h"
#include "function.h"
#include "pattern.h"
#include "projection.h"
#include "value.h"
#include "variable.h"

CUBI_BEGIN_NAMESPACE

class SelectData;

class Select
{

public:
	Select();
	Select(const Select &other);
	Select& operator=(const Select &other);
	bool operator==(const Select &other) const;
	bool operator!=(const Select &other) const;
	~Select();

	void addProjection(const Projection &projection);
	void addProjection(const Variable &variable);
	void addProjection(const Function &function, const Variable &alias = Variable::invalid());
	void addProjection(const Select &select, const Variable &alias = Variable::invalid());
	void addProjection(const LiteralValue &literalValue);

	void addRestriction(const PatternBase &pattern);
	void addRestriction(const Value &s, const Value &p, const Value &o);
	void addRestriction(const Value &s, const ValueChain &chain, const Value &o);

	Filter filter() const;
	void setFilter(const Filter &filter);

	void setLimit(long limit);
	void setOffset(long offset);
	void setOrderBy(const Value &order);

	bool isEmpty() const;

	QList<Projection> projections() const;
	QList<PatternBase> restrictions() const;
	long limit() const;
	long offset() const;
	Value orderBy() const;

	QString sparql(Options::SparqlOptions options = Options::DefaultSparqlOptions) const;

private:
	Variable getTmpVar();

	QSharedDataPointer<SelectData> d;
};

CUBI_END_NAMESPACE

#endif
