/****************************************************************************
 ** This file is part of Cubi, a Sparql query builder for the Qt framework
 **
 ** Copyright (c) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
 **
 ** Contact: Nokia Corporation (info@qt.nokia.com)
 **
 **
 ** GNU Lesser General Public License Usage
 **
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this file.
 ** Please review the following information to ensure the GNU Lesser General
 ** Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** Other Usage
 **
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 ** If you have questions regarding the use of this file, please contact
 ** Nokia at info@qt.nokia.com.
 ****************************************************************************/

#include "value.h"

#include "value_p.h"

CUBI_USE_NAMESPACE

ValueData::~ValueData()
{
}

ValueData*
ValueData::clone()
{
	return new ValueData(*this);
}

bool
ValueData::operator==(const ValueData *other) const
{
	return other->type() == Value::TypeInvalid;
}

Value::Type
ValueData::type() const
{
	return Value::TypeInvalid;
}

bool
ValueData::isValid() const
{
	return false;
}

QString
ValueData::sparql() const
{
	return QString();
}

template<>
ValueData *QSharedDataPointer<ValueData>::clone()
{
	return d->clone();
}

///////////////////////////////////////////////////////////////////////////////

/*!
 * \class Value
 * Base class for all classes that can be used as values.
 */

/*!
 * Returns an invalid Value.
 */
Value::Value()
	: d(new ValueData)
{
}

Value::Value(const Value &other)
	: d(other.d)
{
}

Value::Value(ValueData *data)
	: d(data)
{
}

Value&
Value::operator=(const Value &other)
{
	return d = other.d, *this;
}

Value::~Value()
{
}

bool
Value::operator==(const Value &other) const
{
	if (not isValid() && not other.isValid()) {
		return true;
	}

	return *(d.constData()) == other.d;
}

bool
Value::operator!=(const Value &other) const
{
	return not (d == other.d);
}

Value::Type
Value::type() const
{
	return d->type();
}

/*!
 * Returns \c true is the Value is valid, \c false else.
 */
bool
Value::isValid() const
{
	return d->isValid();
}

QString
Value::sparql() const
{
	return d->sparql();
}
